## These are some examples on how to use Conefor (Saura & Torn, 2009; www.conefor.org) command line from R. 
## The details on the syntax and usage instructions should be found in the manual for Conefor and particularly in those for the command line version.

## In these examples we assume that the executable file of the Conefor command line (conefor.exe) is located in C:/Conefor_from_R (change to a different path if needed)
## We assume that the input files (node file, connection file) for Conefor are all in the same folder
## The result files generated by Conefor will be written in that folder (working directory in R).
## Using the same folder for all these files makes things easier, avoiding the need to write an entire path for each file.

setwd("c:/Conefor_from_R")

## The following calls conefor.exe without any parameter; conefor.exe will therefore just show the syntax to be used
shell("C:/Conefor_from_R/conefor.exe")

## The following calculates the overall index values (not the node-level values) for PC (and EC) in an entire region or landscape (in this case "h1")
## Since the connection file is here a distance file, the parameter "-t dist" could be omitted (this is the default), but is here included to better show the structure of a typical command line in a more general case
shell("C:/Conefor_from_R/conefor.exe -nodeFile nodes_h1.txt -conFile distances_h1.txt -t dist all -confProb 200 0.5 -PC onlyoverall")

## The following calculates the PC (and EC) overall value, dPC (and their fractions) and BC(PC) for every node in the landscape (in this case "h1", as before)
## As in the previous example, the connection file is a distance file, and we omit "-t dist" (this is the default).
shell("C:/Conefor_from_R/conefor.exe -nodeFile nodes_h1.txt -conFile distances_h1.txt -confProb 200 0.36788 -PC -BCPC")


## The following calculates the PC (and EC) overall value, dPC (and their fractions) and BC(PC) for every node in the landscape (in this case "h1", as before)
## but now the connection file is a probability file (therefore the option -confProb is not used)
shell("C:/Conefor_from_R/conefor.exe -nodeFile nodes_h1.txt -conFile probabilities_h1.txt -t prob -PC -BCPC")

## The following calculates (using the interesting option "-*") the overall index values (PC, EC) for all the networks that are located in the same folder (pairs of node and connection files) with file names starting with "nodes_" and connection files starting with "distances_" (see the Conefor command line manual for further details)
## the connection file is a distance file, and we omit "-t dist" (since this is the default).
shell("C:/Conefor_from_R/conefor.exe -nodeFile nodes_ -conFile distances_ -* -confProb 200 0.36788 -PC onlyoverall")

## The following calculates (using the interesting option "-*") the overall index values (PC, EC), and the dPC (and fractions) for every node and for all the networks that are located in the same folder (pairs of node and connection files) with file names starting with "nodes_" and connection files starting with "distances_" (see the Conefor command line manual for further details)
## the connection file is a distance file, and we omit "-t dist" (since this is the default). 
shell("C:/Conefor_from_R/conefor.exe -nodeFile nodes_ -conFile distances_ -* -confProb 200 0.36788 -PC")

## See the Conefor command line version for many other options and parameters